# Crimsy 

Crimsy is a lightweight web framework for building apis in python


## Primary objectives

- Fully typed 
- Small package size (only `msgspec` and `starlette` dependencies)
- Fast 



# Backwards compatibility

Unless **explicitly stated** backwards compatibility is not required and should not be considered.



# Definition of Done

You are ready to commit changes if:

All the lints pass
```
just lint
```
All the tests pass with 100% code coverage
```
just test
```

There should be no `type: ignore` or `type.cast()` in the code unless absolutely necessary.